eigenmorphic: Eigenvalues of morphic subshifts
==============================================

Description
-----------

Eigenvalues of morphic subshifts

License
-------

GPLv3.0

Upstream Contact
----------------

- https://pypi.org/project/eigenmorphic/
- https://github.com/passagemath/passagemath-pkg-eigenmorphic
